#
# spec file for package joda-time
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global spec_version 2.12
%global tzversion tzdata2024a
Name:           joda-time
Version:        %{spec_version}.7
Release:        1.1
Summary:        Java date and time API
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://www.joda.org/joda-time/
Source0:        https://github.com/JodaOrg/%{name}/archive/v%{version}.tar.gz
Source1:        ftp://ftp.iana.org/tz/releases/%{tzversion}.tar.gz
Source100:      %{name}-build.xml
BuildRequires:  ant
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  joda-convert
BuildArch:      noarch

%description
Joda-Time provides a quality replacement for the Java date
and time classes. The design allows for multiple calendar
systems, while still providing a simple API. The 'default'
calendar is the ISO8601 standard which is used by XML. The
Gregorian, Julian, Buddhist, Coptic and Ethiopic systems
are also included, and we welcome further additions.
Supporting classes include time zone, duration, format
and parsing.

%package        javadoc
Summary:        Javadocs for %{name}
Group:          Documentation/HTML

%description    javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q

dos2unix LICENSE.txt NOTICE.txt RELEASE-NOTES.txt
cp %{SOURCE100} build.xml

# all java binaries must be removed from the sources
find . -name '*.jar' -exec rm -f '{}' \;

# replace internal tzdata
rm -f src/main/java/org/joda/time/tz/src/*
tar -xzf %{SOURCE1} -C src/main/java/org/joda/time/tz/src/

%build
%{ant} \
  -Dproject.version=%{version} \
  -Dproject.spec.version=%{spec_version} \
  -Djoda-convert.jar=%{_javadir}/joda-convert.jar \
  clean jar javadoc

%install
# jars
install -dm0755 %{buildroot}%{_javadir}
# Don't install a versioned jar and symlink to it, instead install
# the unversioned jar as per Java Packaging Guidelines
install -m0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar
# poms
install -dm0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar
# javadoc
install -dm0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE.txt NOTICE.txt
%doc RELEASE-NOTES.txt

%files javadoc
%license LICENSE.txt NOTICE.txt
%{_javadocdir}/%{name}

%changelog
* Thu Sep  5 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Upgrade to version 2.12.7
  * Update time zone data to 2024agtz
- Upgrade to version 2.12.6
  * Enhance DateTimeZone.forID() to better match java.time. Fixes
    [#733], #717.
  * Better error message in DateTimeFormat. Fixes #731.
  * DateTimeZone data updated to version 2023dgtz.
- Upgrade to version 2.12.5
  * DateTimeZone data updated to version 2023cgtz.
- Upgrade to version 2.12.4
  * DateTimeZone data updated to version 2023bgtz.
- Upgrade to version 2.12.3
  * DateTimeZone data updated to version 2023agtz.
- Upgrade to version 2.12.2
  * DateTimeZone data updated to version 2022ggtz.
- Upgrade to version 2.12.1
  * Add/fix translations for iw, sq.
  * DateTimeZone data updated to version 2022fgtz.
- Upgrade to version 2.12.0
  * Add translations for ca, el, eu, fi, hi, hu, in, iw, ms, nn,
    ro, sk, sv, zh.
  * DateTimeZone data updated to version 2022egtz.
- Upgrade to version 2.11.2
  * DateTimeZone data updated to version 2022dgtz.
  * Switch LGTM to CodeQL.
- Upgrade to version 2.11.1
  * Update build scripts and fix static analysis warnings.
  * Switch master to main.
  * DateTimeZone data updated to version 2022cgtz.
- Upgrade to version 2.11.0
  * Change DateTimeZone to use
    'org.joda.time.DateTimeZone.Timezone' instead of
    'user.timezone'. This change causes Joda-Time to query
    'TimeZone.getDefault()' in most cases. In most cases this
    change will have no effect on application code, as
    'user.timezone' will be picked up by 'TimeZone.getDefault()'
    instead. If you specifically need to stop Joda-Time calling
    'TimeZone.getDefault()' then you will need to change to use the
    new system property 'org.joda.time.DateTimeZone.Timezone'.
    Fixes #587.
  * Avoid using == on objects. Fixes #581.
  * DateTimeZone data updated to version 2022bgtz. This uses the
    new global-tz project that reinstates all the data removed by
    IANA's TZDB. See
    https://github.com/JodaOrg/joda-time/issues/566
- Upgrade to version 2.10.14
  * DateTimeZone data updated to version 2022agtz. This uses the
    new global-tz project that reinstates all the data removed by
    IANA's TZDB. See
    https://github.com/JodaOrg/joda-time/issues/566
- Upgrade to version 2.10.13
  * DateTimeZone data updated to version 2021efork. See
    https://github.com/JodaOrg/joda-time/issues/566
- Upgrade to version 2.10.12
  * DateTimeZone data updated to version 2021bfork3. See
    https://github.com/JodaOrg/joda-time/issues/566
- Upgrade to version 2.10.11
  * Defend against possible release of hugely damaging timezone
    data. See https://github.com/JodaOrg/joda-time/issues/566
- Upgrade to version 2.10.10
  * DateTimeZone data updated to version 2021a.
- Upgrade to version 2.10.9
  * DateTimeZone data updated to version 2020e. Fix to time-zone
    compiler.
- Upgrade to version 2.10.8
  * DateTimeZone data updated to version 2020d. Remove systemv and
    pacificnew time zones as per TZDB changes.
- Upgrade to version 2.10.7
  * DateTimeZone data updated to version 2020c. Remove systemv and
    pacificnew time zones as per TZDB changes.
  * Better error message for year-month-day. Fixes #540.
  * Fix localization for Russia. Fixes #533.
- Upgrade to version 2.10.6
  * DateTimeZone data updated to version 2020a.
  * Add localization for Ukraine. Fixes #523.
- Upgrade to version 2.10.5
  * Updated Joda-Convert version.
- Upgrade to version 2.10.4
  * DateTimeZone data updated to version 2019c.
- Upgrade to version 2.10.3
  * DateTimeZone data updated to version 2019b.
- Remove patch:
  * joda-time-fix-tests.patch
    + not needed anymore
- Add JPMS and OSGI metadata to the manifest
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Wed Feb  6 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.10.1
  * Fix time-zone compiler for Namibia. Fixes #485.
  * Fix time-zone compiler for Tokyo.
  * Handle negative SAVE values in tzdb.
  * Add Instant.EPOCH. See #472.
  * Clarify negative durations. See #465.
  * Add Instant.ofEpochMilli(). Add Instant.ofEpochSecond().
    Fixes #458.
  * Add automatic module name for Java SE 9.
  * Add Kazakh language translations. Fixes #446
  * Avoid double addition when using lenient chronology. Fixes #432.
  * Clarify Period.fieldDifference() Javadoc.
  * Clarify Instant.withMillis() Javadoc. Fixes jodaorg.github.io#5
  * Add ZoneInfoProvider() constructor.
  * Optimise release process.
  * DateTimeZone data updated to version 2017b.
  * Handle plus/minus of Integer.MIN_VALUE/MAX_VALUE months
    correctly. Fixes #418.
  * Clarify time fields are based on the local time-line.
    Fixes #415.
  * Fix spelling mistakes. Fixes #412.
  * Fix DateTimePrinterInternalPinter that outputs data twice.
    Fixes #409.
  * Support conversion of old TimeZone where name has digits other
    than ASCII [#381]
  * Add Norwegian period translations [#378]
  * Add Duration.dividedBy(long,RoundingMode) [#69, #379]
  * Fixed bug where clock read twice when comparing two nulls in
    DateTimeComparator [#404]
  * Fixed minor issues with historic time-zone data [#373]
  * Fix bug in time-zone binary search [#332, #386] The fix in
    v2.9.2  caused problems when the time-zone being parsed was not
    the last element in the input string. New approach uses a
    different approach to the problem.
  * Update tests for JDK 9 [#394]
  * Close buffered reader correctly in zone info compiler [#396]
  * Handle locale correctly zone info compiler [#397]
  * Loading time-zone provider now occurs in a privileged block
    [#327, #375]
  * Make DateTimeUtils.SYSTEM_MILLIS_PROVIDER public [#357]
  * Fix bug when adding months at the maximum limits of integer
    [#361]
  * Add Turkish period translations [#364]
  * Fix bug in time-zone binary search [#332]
  * Minor fixes to code internals [#339, #326, #344, #350, #343]
  * Better document behaviour [#325]
  * Fix bug introduced by Long.MIN_VALUE and Long.MAX_VALUE changes
    [#328]
  * Faster parsing of time-zone identifiers [#282]
  * Added Interval.parseWithOffset(String) [#299, #296] Provides a
    way to parse the fixed offset in an interval string
  * Add DateTimeFormatter methods for StringBuilder [#298]
  * Add Russian period translations [#320]
  * Add Italian period translations [#312]
  * Add Czech period translations [#313]
  * Clarify that PeriodFormatterBuilder is in an invalid state once
    built [#309]
  * Allow DateTime and Interval to refer to values at Long.MIN_VALUE
    and Long.MAX_VALUE [#297, #190] A DateTime may be created with
    any millisecond value, however at the very edges there may be
    some undesirable effects, for example always using UTC instead
    of the time-zone
  * Better error message for malformed tzdb files [#319]
  * Better error message for interval constructor [#321]
  * Fixed to handle JDK 8u60 [#288, #291] Without this fix,
    formatting a time-zone will print "+00:00" instead of "GMT" for
    the GMT time-zone
  * Fix parsing of basic form ISO style where year has unnecessary
    plus sign [#86] For example, +20151030 will now be correctly
    parsed as year 2015.
  * Fix overflow bug in intervals [#315]
- Removed patches:
  * joda-time-1.6-sourcetarget.patch
    + correct source and target levels specified in the ant
  build.xml file
  * joda-time-use-system-junit.patch
    + not needed any more, since we are not running tests for the
  while
- Added patch:
  + joda-time-fix-tests.patch
    + fix java version parsing for versions > 9
- DateTimeZone data updated to version 2018i
- Add build.xml file to allow build with ant
* Mon Nov 19 2018 Fridrich Strba <fstrba@suse.com>
- Add maven pom file and register joda-time as a maven artifact
* Tue Sep 19 2017 fstrba@suse.com
- Added patch:
  * joda-time-1.6-sourcetarget.patch
    + make compile.source and compile.target properties that can be
    specified on command-line
- Build with java source and target level 1.6 in order to allow
  building with jdk9
* Tue Jul  8 2014 tchvatal@suse.com
- Do not depend on ant-nodeps.
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Wed Apr 28 2010 ro@suse.de
- update timezone data to current 2010h
* Wed Apr 28 2010 ro@suse.de
- remove needless buildroot cleaning st start of install section
* Thu Jul 23 2009 rel-eng@lists.fedoraproject.org
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild
* Tue Feb 24 2009 rel-eng@lists.fedoraproject.org
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild
* Thu Dec 11 2008 konrad@tylerc.org
- New upstream version (1.6).
* Thu Oct 30 2008 konrad@tylerc.org
- New tzdata.
* Sun Oct 12 2008 konrad@tylerc.org
- New tzdata (2008g).
* Fri Aug 22 2008 konrad@tylerc.org
- New version with new tzdata (2008e).
* Fri Jul 18 2008 konrad@tylerc.org
- New version with new tzdata (2008d).
* Sun Jun  8 2008 konrad@tylerc.org
- New version with new tzdata (2008c).
* Sat Apr  5 2008 konrad@tylerc.org
- Don't compile GCJ bits yet as we hit some GCJ bug.
* Fri Apr  4 2008 konrad@tylerc.org
- Update to tzdata2008b.
- Use unversioned jar.
- Some small things to comply with Java Packaging Guidelines.
- GCJ support.
* Sun Mar 16 2008 konrad@tylerc.org
- Many small changes from bz# 436239 comment 6.
- Change -javadocs to -javadoc in accordance with java packaging
  guidelines draft.
* Sat Mar 15 2008 konrad@tylerc.org
- Use system junit via Mamoru Tasaka's patch.
* Sun Mar  2 2008 konrad@tylerc.org
- Initial package.
